@@ -1,4 +1,4 @@
-from protmo.server.server import run_server
+from .server.server import run_server
 # from protmo.provide.server import provide
 # from protmo.server.server import DB_KEY
 # from protmo.db.server import Db
